# Matplotlib Drawers

Utilities for drawing real time data stream figures using matplotlib and also some general classification metric plots

## Real time plotting

- [Multi]-series scroll plot
- Discrete waterfall plot
- Distribution plot
- FFT scroll plot

## Evaluation

- Metric overview plots
